*****************************************************************************************
* FILE:     C:\Projects\Stata Weighting Book\Program files\5 Wts for Var Est\Ex.5.11_multsteps.survwgt.do
* PROJECT:  Stata weighting book
* DATE:     03/02/2017
* AUTHOR:   R. Valliant
* PURPOSE:  Illustrate replication for multiple steps with survwgt
*****************************************************************************************

log using "C:\Projects\Stata Weighting Book\Program files\5 Wts for Var Est\Ex.5.11_multsteps.survwgt.smcl"

set more off
use "C:\Projects\Stata Weighting Book\Data\nhis\nhis.logistnr.dta",	clear					 

recode age_r (3=3) (4=4) (5=5) (6=6) (7=6) (8=6), gen(age_r1) 
label define age_lab 3 "18-24" 4  "25-44" 5 "45-64" 6 "65+"
label values age_r1 age_lab

label define ed_lab 1 "High school or less" 2 "Some college" 3 "Bachelor or assoc" 4  "Master's & higher"
label values educ_r ed_lab

gen svywt1 = svywt/1000

	* tab counts in age_r1 x hisp table before adjustment
svyset psu [pweight = svywt1], strata(stratum)
svy: tab age_r1 hisp, count se format(%12.0f)

	* create JKn base weights using svywt1
survwgt create jkn, psu(psu) strata(stratum) weight(svywt1) stem(JKn_)
svrtab age_r1 hisp, count format(%12.0f)
	* use pclass variable created in Example 3.2 for NR adjustment cells
survwgt nonresponse [all], by(pclass) respvar(resp) stem(JKn_NR)

	* check some wt sums
summarize svywt1 
summarize JKn_1
summarize JKn_NR1 if resp==1
summarize JKn_NR174 if resp==1
	 
svrset set pw JKn_NR0  rw "JKn_NR1 - JKn_NR174"
svrtab age_r1 hisp, count se format(%12.1f)
svrtab educ_r hisp, count se format(%12.1f)

	* Rake to age_r1 and hisp margins
	* create age_r1 and hisp totals to illustrate undercoverage
gen age_tot     = 1700 
replace age_tot = 5000 if age_r1 == 4
replace age_tot = 4500 if age_r1 == 5
replace age_tot = 2200 if age_r1 == 6

gen hisp_tot     = 12060 
replace hisp_tot =  1340  if hisp == 2
	
survwgt rake [all], by(age_r1 hisp) totvars(age_tot hisp_tot) stem(JKNRrake)
svrtab educ_r hisp, count se format(%12.1f)

svyset psu [pw = JKNRrake0], strata(stratum)
svy: tab educ_r hisp if resp==1, count se stubwidth(19)

log close
